@@ -423,7 +423,7 @@ class Paramater():
         result[ 'is_array' ] = True
       if self.default is not notset:
         if callable( self.default ):
-          result[ 'default' ] = '<callable "{0}">'.format( self.default.__name__ )
+          result[ 'default' ] = converter.fromPython( self, self.default() )
         else:
           result[ 'default' ] = converter.fromPython( self, self.default )
 
@@ -579,9 +579,10 @@ class Namespace( Element ):
 
 
 class Model( Element ):
-  def __init__( self, field_list, transaction_class, list_filter_map=None, constant_set_map=None, not_allowed_verb_list=None, *args, **kwargs ):
+  def __init__( self, field_list, transaction_class, id_field_name=None, list_filter_map=None, constant_set_map=None, not_allowed_verb_list=None, *args, **kwargs ):
     super().__init__( *args, **kwargs )
     self.transaction_class = transaction_class
+    self.id_field_name = id_field_name
     self.field_map = {}
     for field in field_list:
       if not isinstance( field, Field ):
@@ -636,8 +637,10 @@ class Model( Element ):
     for name in self.constant_set_map:
       data[ 'constants' ][ name ] = self.constant_set_map[ name ]
     data[ 'fields' ] = [ item.describe( converter ) for item in self.field_map.values() ]
+    if self.id_field_name:
+      data[ 'id-field-name' ] = self.id_field_name
     data[ 'actions' ] = [ item.path for item in self.action_map.values() ]
-    data[ 'not-allowed-methods' ] = self.not_allowed_verb_list
+    data[ 'not-allowed-verbs' ] = self.not_allowed_verb_list
     data[ 'list-filters' ] = {}
     for name in self.list_filter_map:
       data[ 'list-filters' ][ name ] = [ item.describe( converter ) for item in self.list_filter_map[ name ].values() ]
@@ -1122,7 +1125,7 @@ class Server():
 
     try:
       ( path, model, action, id_list, multi ) = self.uri.split( request.uri )
-    except ValueError as e:
+    except ValueError:
       return Response( 400, data={ 'message': 'Unable to Parse "{0}"'.format( request.uri ) } )
 
     if id_list is not None and len( id_list ) > __MULTI_URI_MAX__:
@@ -1236,7 +1239,11 @@ class Server():
 
     except Exception as e:
       if in_transaction:
-        transaction.abort()
+        try:
+          transaction.abort()
+        except Exception:  # TODO: put some logging in here, this should be a warning log
+          pass
+
       raise e
 
     if result is None:
